@@ -1,10 +1,6 @@
 """
-    Blackboard Grade center analyser
-    A tool to analyse assignments downloaded from the Blackboard grade center
+    Blackboard Analysis Tools
     Copyright 2013, Jeroen Doggen, jeroendoggen@gmail.com
-
-    This file is needed to import the module properly
-
 """
 
 import sys
